@@ -1,4 +1,4 @@
-
+from __future__ import print_function
 
 def init_napoleon_colab():
     from napoleontoolbox.signal import signal_utility
@@ -6,7 +6,7 @@ def init_napoleon_colab():
     from datetime import datetime
     import pandas as pd
     from napoleontoolbox.file_saver import dropbox_file_saver
-    from __future__ import print_function
+
     from ipywidgets import interact, interactive, fixed, interact_manual
     import ipywidgets as widgets
     from napoleontoolbox.utility import metrics
@@ -22,6 +22,15 @@ def init_napoleon_colab():
     import plotly
     from plotly.offline import iplot
 
+    import os
+    stream = os.popen('pip install dropbox')
+    output = stream.read()
+    print(output)
+
+    stream = os.popen('pip install plotly==4.7.1')
+    output = stream.read()
+    print(output)
+
     def configure_plotly_browser_state():
       import IPython
       display(IPython.core.display.HTML('''
